SoCLI Changelog
================


Release 3.5 
---------------------------

* Added code to prevent unwanted captcha checks
* Made SoCLI more interactive
* Minor bugfixes

Release 3.4 
---------------------------

* Bugfix release

Release 3.3
---------------------------

* Minor bugfix 

Release 3.2
---------------------------

* Added user profiles 

Release 3.1
---------------------------

* Bugfix release

Release 3.0
---------------------------

* Fixed almost all windows encoding and color bugs

Release 2.9
---------------------------

* Many minor bug fixes

Release 2.8
---------------------------

* Fixed Windows encoding problem

Release 2.7
---------------------------

* Fixed some minor bugs

Release 2.6
---------------------------

* Fixed some minor typos
* Added windows binary release

Release 2.5
---------------------------

* Fixed some bugs due to latest windows cmd update
* Added sorting of question based on number of votes

Release 2.4
---------------------------

* Added StackOverflow attribution

Release 2.3
---------------------------

* Fixed minor bugs

Release 2.2
---------------------------

* Added tag based search

Release 2.1
---------------------------

* Fixed encoding bug

Release 2.0
---------------------------

* Fixed bugs on python 2

Release 1.9
---------------------------

* Added URL support to answers
* Added debugger module

Release 1.8
---------------------------

* Added support to python 2

Release 1.7
---------------------------

* Added new question feature
* Fixed windows color problem on windows 10

Release 1.6
---------------------------

* Intelligent colors

Release 1.5
---------------------------

* Added open in browser feature

Release 1.4
---------------------------

* Added interactive mode feature

Release 1.3
---------------------------

* Added colors

Release 1.2
---------------------------

* First stable release on PyPI

Release 1.1
---------------------------

* Pre Release

Release 1.0
---------------------------

* Beta version
